function [logP,logP0]=bspect(y,wmin,wmax,Nw,Kmin,Kmax,dK)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% function [logP,logP0]=bspect(y,wmin,wmax,Nw,Kmin,Kmax,dK)
% computes the bayes factor for equidistant
% frequencies in the interval [wmin,wmax]
% and for the harmonics Kmin, Kim+dK, Kmin+2dK,...,Kmax
% 
%  logP is an Nw*NK array of un-nomalized log bayes factors
%  logP0 is an un-normalized bayes factor for white noise
%
% (c) L.K. Hansen (2003)
%
[T,D]=size(y);
sig2y=y'*y/T;
logP0=(3/2)*log(sig2y)-((1+T)/2)*log((T-1)*sig2y);
if D~=1,
    disp('x must be T*1 array')
    break
end;
index=(1:T)*2*pi;
q=1.0;
if Kmin < 1,
    disp('Kmin must be >= 1')
    break
end
Ks=Kmin:dK:Kmax;
K=length(Ks);
logP=zeros(Nw,K);
for k=1:K,
 for j=1:Nw,
   w=wmin + (wmax-wmin)*(j-1)/(Nw-1);
   warr(j)=w;
   X=[sin(w*index);cos(w*index)];
   for r=2:k,
      X=[X;sin(r*w*index);cos(r*w*index)];
   end
   X=X';
   A=X'*X;
   nu=T/trace(A);
   L=size(A,1);
   iVp=A+(1/nu)*eye(L);;
   f=X'*y;
   Q=(T+1)*sig2y -f'*pinv(iVp)*f;
   logP(j,k)=-log(det(iVp))/2 + (L/2)*log(nu) - ((T+3)/2)*log(abs(Q))+(3/2)*log(sig2y);
 end
end

